@@ -1,21 +1,20 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs"
 
 @addTupleType
 export class ChunkedIndexModelSetTuple extends Tuple {
-    public static readonly tupleName = chunkedIndexTuplePrefix + "ModelSetTuple";
-
+    public static readonly tupleName = chunkedIndexTuplePrefix + "ModelSetTuple"
+    
     //  A protected variable
-    id__: number;
-
+    id__: number
+    
     //  The unique key of this ModelSet
-    key: string;
-
+    key: string
+    
     //  The unique name of this ModelSet
-    name: string;
-
+    name: string
+    
     constructor() {
         super(ChunkedIndexModelSetTuple.tupleName)
     }
-
+    
 }
\ No newline at end of file
