@@ -1,22 +1,21 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs"
 
 @addTupleType
 export class ChunkedTypeTuple extends Tuple {
-    public static readonly tupleName = chunkedIndexTuplePrefix + "ChunkedTypeTuple";
-
+    public static readonly tupleName = chunkedIndexTuplePrefix + "ChunkedTypeTuple"
+    
     //  A protected variable
-    id__: number;
-
+    id__: number
+    
     //  The key of this ChunkedType
-    key: string;
-
+    key: string
+    
     //  The key of the model set
-    modelSetKey: string;
-
+    modelSetKey: string
+    
     //  The name of the ChunkedType
-    name: string;
-
+    name: string
+    
     constructor() {
         super(ChunkedTypeTuple.tupleName)
     }
